@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Database Object Interface - ~/lib/DB/Object/Fields/Field.pm
-## Version v1.1.0
+## Version v1.1.1
 ## Copyright(c) 2023 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/01/01
-## Modified 2023/11/10
+## Modified 2024/01/03
 ## All rights reserved
 ## 
 ## 
@@ -52,7 +52,7 @@ BEGIN
         fallback => 1,
     );
     use Want;
-    our $VERSION = 'v1.1.0';
+    our $VERSION = 'v1.1.1';
 };
 
 use strict;
@@ -337,7 +337,7 @@ sub _op_overload
     }
     elsif( $dbo->placeholder->has( $self->_is_scalar( $val ) ? $val : \$val ) )
     {
-        $types = $dbo->placeholder->replace( \$val );
+        $types = $dbo->placeholder->replace( $self->_is_scalar( $val ) ? $val : \$val );
     }
     # A placeholder, but don't know the type
     elsif( $val =~ /^$placeholder_re$/ )
@@ -465,7 +465,7 @@ This would yield:
 
 =head1 VERSION
 
-    v1.1.0
+    v1.1.1
 
 =head1 DESCRIPTION
 
